@@ -1,4 +1,4 @@
-package Pcore::Whois v0.3.0;
+package Pcore::Whois v0.3.1;
 
 use Pcore -class, -const;
 use Pcore::Util::Scalar qw[blessed];
@@ -28,7 +28,7 @@ has requests_queue => ( is => 'ro', isa => ArrayRef, default => sub { [] }, init
 has threads => ( is => 'ro', isa => PositiveOrZeroInt, default => 0, init_arg => undef );           # total active threads num.
 
 sub BUILDARGS ( $self, $args ) {
-    $args->{ip_pool} = P->class->losd('Pcore::AE::Handle::IPPool')->new( { ip => $args->{ip_pool} } ) if $args->{ip_pool} && !blessed $args->{ip_pool};
+    $args->{ip_pool} = P->class->load('Pcore::AE::Handle::IPPool')->new( { ip => $args->{ip_pool} } ) if $args->{ip_pool} && !blessed $args->{ip_pool};
 
     return $args;
 }
